@@ -1,5 +1,5 @@
-#include "nl80211.h"
 #include "iw.h"
+#include "nl80211.h"
 
 int mac_addr_n2a(char *mac_addr, unsigned char *arg)
 {
@@ -65,3 +65,27 @@ const char *iftype_name(enum nl80211_iftype iftype)
 	sprintf(modebuf, "Unknown mode (%d)", iftype);
 	return modebuf;
 }
+
+int ieee80211_channel_to_frequency(int chan)
+{
+	if (chan < 14)
+		return 2407 + chan * 5;
+
+	if (chan == 14)
+		return 2484;
+
+	/* FIXME: dot11ChannelStartingFactor (802.11-2007 17.3.8.3.2) */
+	return (chan + 1000) * 5;
+}
+
+int ieee80211_frequency_to_channel(int freq)
+{
+	if (freq == 2484)
+		return 14;
+
+	if (freq < 2484)
+		return (freq - 2407) / 5;
+
+	/* FIXME: dot11ChannelStartingFactor (802.11-2007 17.3.8.3.2) */
+	return freq/5 - 1000;
+}
